function fem = rdme2fem(fem,U,vol,tspan)
%RDME2FEM Create FEM-structure given output from RDME.
%   FEM = RDME2FEM(FEM,U,vol,TSPAN) Inserts solution matrix U into FEM.
%
%   Input argument vol is the list of cell volumes, as usually obtained via
%   FEM2RDME.
%
%   The argument TSPAN is optional and defaults to FEM.sol.tlist.
%
%   See also FEM2RDME, RDME.

% J. Cullhed 2008-08-06

% extend mesh
if ~isfield(fem,'xmesh')
  fem.xmesh = meshextend(fem);
end

% fundamentals
nodes = xmeshinfo(fem.xmesh,'out','nodes');
[Mspecies,Ncells] = size(nodes.dofs);
Ndofs = Mspecies*Ncells;

% permutation of species
[foo,sp] = ismember(fem.equ.dim,nodes.names);
isp(sp) = 1:numel(sp);

% scale and permute back
U = reshape(U,Mspecies,Ncells,[]);

% does not work well on the Mac:
%U = tprod(U(isp,:,:),1./(6.022e23*vol(:)),[1 2 3],[2 4]);
% suboptimal, but should work ok:
V = repmat(vol(:)'*6.022e23,[Mspecies 1]);
for i = 1:numel(tspan)
  U(:,:,i) = U(:,:,i)./V;
end

% final shape
U = reshape(U(isp,:,:),Ndofs,[]);

% check for tspan
if nargin < 4
  tspan = fem.sol.tlist;
end

% final call
fem.sol = femsol(U, 'tlist', tspan);

