function make(propensity_file)
%MAKE Makefile for MEXRDME.
%   MAKE(P) Makes URDME with propensity source file P.

% J. Cullhed 2008-06-18

% Find path.
path=[pwd '/'];
define=[];

% Set propensity file. This defaults to propensities.h.
if nargin>0
  if strcmp(propensity_file,'test')
    propensity_source=[path '../test/spin_propensities.c '];
  else
    propensity_source=[path propensity_file ' '];
  end
else
   error('No target to make.'); 
end

% Include and source directories.
include = ['-I' path '../include'];
link= ['-L' path '../src'];

% Mex extension.
mx = mexext;

% Amd 64.
if strcmp(mx,'mexa64')
  define=[define '-DMALLOC\(n\)=mxMalloc\(n\) -DFREE\(p\)=mxFree\(p\)'];
  cc='CC=gcc';
  cflags='CFLAGS=-O3 -ftree-vectorize -Wall -pedantic -fPIC -std=gnu99 ';
  cflags=[cflags define];
  ldflags='LFLAGS=-pthread';
  source=[path '../src/mexrdme.c ' propensity_source  path ...
          '../src/rdme.c ' path '../src/binheap.c ' path '../src/report.c'];

  mex(cc, cflags, include, ldflags, '-largeArrayDims', link, source)

% Intel Mac gcc.
elseif strcmp(mx,'mexmaci')
  define=[define '-DMALLOC\(n\)=mxMalloc\(n\) -DFREE\(p\)=mxFree\(p\)'];
  cc='CC=gcc';  
  cflags='CFLAGS=-O3 -ftree-vectorize -Wall -fPIC -std=gnu99 ';
  cflags=[cflags define];
  ldflags='LFLAGS=-bundle -flat_namespace --no-undefined';
  source=[path '../src/mexrdme.c ' propensity_source  path ...
          '../src/rdme.c ' path '../src/binheap.c ' path '../src/report.c'];

  mex(cc, cflags, include,ldflags, '-largeArrayDims', link, source)
else
  error(['Platform not yet supported. Your mex extension is ' mx ...
         '. Please edit make.m to allow for this extension.']);
end

